You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@qpid.apache.org by ar...@apache.org on 2007/08/07 10:01:07 UTC

svn commit: r563417 - /incubator/qpid/trunk/qpid/java/client/src/main/java/org/apache/qpidity/client/Session.java

Author: arnaudsimon
Date: Tue Aug  7 01:01:06 2007
New Revision: 563417

URL: http://svn.apache.org/viewvc?view=rev&rev=563417
Log:
changed messageFlush to return an int

Modified:
    incubator/qpid/trunk/qpid/java/client/src/main/java/org/apache/qpidity/client/Session.java

Modified: incubator/qpid/trunk/qpid/java/client/src/main/java/org/apache/qpidity/client/Session.java
URL: http://svn.apache.org/viewvc/incubator/qpid/trunk/qpid/java/client/src/main/java/org/apache/qpidity/client/Session.java?view=diff&rev=563417&r1=563416&r2=563417
==============================================================================
--- incubator/qpid/trunk/qpid/java/client/src/main/java/org/apache/qpidity/client/Session.java (original)
+++ incubator/qpid/trunk/qpid/java/client/src/main/java/org/apache/qpidity/client/Session.java Tue Aug  7 01:01:06 2007
@@ -16,11 +16,15 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-package org.apache.qpidity;
+package org.apache.qpidity.client;
 
 import java.util.Map;
 
 import org.apache.qpidity.api.Message;
+import org.apache.qpidity.QpidException;
+import org.apache.qpidity.Header;
+import org.apache.qpidity.Option;
+import org.apache.qpidity.Range;
 
 /**
  * <p>A session is associated with a connection.
@@ -44,7 +48,7 @@
     /**
      * Close this session and any associated resources.
      *
-     * @throws QpidException If the communication layer fails to close this session or if an internal error happens
+     * @throws org.apache.qpidity.QpidException If the communication layer fails to close this session or if an internal error happens
      *                       when closing this session resources. .
      */
     public void close() throws QpidException;
@@ -181,7 +185,7 @@
      *                    <li> pre-acquire (1): the message is acquired when the transfer starts
      *                    </ul>
      * @param listener    The listener for this destination. When big message are transfered then
      *                    it is recommended to use a {@link MessagePartListener}.
      * @param options     Set of Options.
      * @param filter      A set of filters for the subscription. The syntax and semantics of these filters depends
      *                    on the providers implementation.
@@ -181,7 +185,7 @@
      *                    </ul>
      * @param listener    The listener for this destination. When big message are transfered then
-     *                    it is recommended to use a {@link MessagePartListener}.
+     *                    it is recommended to use a {@link org.apache.qpidity.client.MessagePartListener}.
      * @param options     Set of Options.
      * @param filter      A set of filters for the subscription. The syntax and semantics of these filters depends